#[non_exhaustive]pub struct ImagePackImage {
pub url: OwnedMxcUri,
pub body: Option<String>,
pub info: Option<ImageInfo>,
}Expand description
An image object in a image pack.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: OwnedMxcUriThe MXC URI to the media file.
body: Option<String>An optional text body for this image.
Useful for the sticker body text or the emote alt text.
Defaults to the shortcode.
info: Option<ImageInfo>The ImageInfo object used for the info block of m.sticker events.
Implementations
Sourceimpl ImagePackImage
impl ImagePackImage
Sourcepub fn new(url: OwnedMxcUri) -> Self
pub fn new(url: OwnedMxcUri) -> Self
Creates a new ImagePackImage with the given MXC URI to the media file.