#[non_exhaustive]pub struct ImagePackMeta {
pub display_name: Option<String>,
pub avatar_url: Option<OwnedMxcUri>,
pub usage: BTreeSet<PackUsage>,
pub attribution: Option<String>,
}Expand description
Details about an image pack.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: Option<String>A display name for the pack.
If absent and the pack is defined in a room, defaults to the room’s name.
avatar_url: Option<OwnedMxcUri>The MXC URI of an avatar for the pack.
If absent and the pack is defined in a room, defaults to the room’s avatar.
usage: BTreeSet<PackUsage>The intended usage(s) for this pack.
If empty, all usage types are assumed.
attribution: Option<String>The attribution of this pack.
For crediting the original author or source, for example.
Implementations
Sourceimpl ImagePackMeta
impl ImagePackMeta